Changelog
=========

### v0.1.0 / 2022-10-12

##### Features

  - Add Django 3.2 support (#11).

##### Misc

  - Update Web2018 from 5.2.0 to 6.1.1 (#15).

### v0.0.2 / 2021-07-21

##### Features

  - Add online template (#2).

##### Improvements

  - Add alt attribute for images (#6).

##### Fixes

  - Fix blue links in GMail (#8).
  - Fix typo in logo.inc.html (#7).

##### Misc

  - Add release workflow to PyPI (#5).
  - Update black from 21.5b2 to 21.6b0 (#3).
  - Update isort from 5.8.0 to 5.9.2 (#4).

### v0.0.1 / 2021-06-17

  - First version, released on an unsuspecting world.
